@@ -15,10 +15,11 @@ server <- function(input, output) {
   
 output$pivotRefresh <- renderText({
 
-cnames <- list("cols","rows","vals", "exclusions","aggregatorName", "rendererName")
+cnames <- list("cols","rows","vals", "exclusions","inclusions", "aggregatorName", "rendererName")
 # Apply a function to all keys, to get corresponding values
 allvalues <- lapply(cnames, function(name) {
   item <- input$myPivotData[[name]]
+  print(item)
   if (is.list(item)) {
     list_to_string(item, name)
   } else {
@@ -29,7 +30,20 @@ paste(allvalues, collapse = "\n")
 })
 
 output$mypivot = renderRpivotTable({
-    rpivotTable(data=cars, onRefresh=htmlwidgets::JS("function(config) { Shiny.onInputChange('myPivotData', config); }"))
+    rpivotTable(
+      Titanic,
+      rows = "Survived",
+      cols = c("Class","Sex"),
+      aggregatorName = "Sum as Fraction of Columns",
+      exclusions = list(
+        Survived = list("No")
+        # ,
+        # Class = list("1st")
+      ),
+      vals = "Freq",
+      rendererName = "Table Barchart",
+      onRefresh=htmlwidgets::JS("function(config) { Shiny.onInputChange('myPivotData', config); }")
+      )
   })
 }
 
